@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9716 2017-01-13 13:24:44Z Lavender $
+# $Id: __init__.py 9742 2017-02-08 01:01:19Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2017-01-13 21:24:44 +0800 (Fri, 13 Jan 2017) $
-# $Revision: 9716 $
+# $Author: David $ (last)
+# $Date: 2017-02-08 09:01:19 +0800 (Wed, 08 Feb 2017) $
+# $Revision: 9742 $
 
 import os
 import sys
@@ -68,6 +68,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     emailDefaults = {
         'ACCOUNT_EMAIL_CONFIRMATION_REQUIRED' : True,
         'EMAIL_BACKEND' : 'django.core.mail.backends.smtp.EmailBackend',
+        'OSCAR_FROM_EMAIL' : settingsDict['DEFAULT_FROM_EMAIL']
     }
     
     warnWithout('EMAIL_BACKEND', settingsDict, emailDefaults)
@@ -124,17 +125,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     }
     update(settingsDict, ADDING_HAYSTACK_CONNECTIONS)
     #=========================================================================
-    # Oscar default currency
-    ADDING_OSCAR_DEFAULT_CURRENCY = {
-        'OSCAR_DEFAULT_CURRENCY' : 'USD'
-    }
-    update(settingsDict, ADDING_OSCAR_DEFAULT_CURRENCY)
 
-    # Site id
-    ADDING_SITE_ID = {
-        'SITE_ID' : 1
-    }
-    update(settingsDict, ADDING_SITE_ID)
     #=========================================================================
     if enablePaypal:
         require('PAYPAL_API_USERNAME', settingsDict)
